ar1021_i2c simply also supports the ar1020 device I'm using. This is
tested. They also share the same datasheet:

   http://ww1.microchip.com/downloads/en/DeviceDoc/40001393C.pdf

So let users see that they have a compatible in front of them by adding
AR1020 to the driver's description.

Signed-off-by: Martin Kepplinger <martin.kepplin...@ginzinger.com>
---

revision history
----------------
v2: leave compatible string untouched. only add description.
v1: initial idea.


 drivers/input/touchscreen/Kconfig      | 4 ++--
 drivers/input/touchscreen/ar1021_i2c.c | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/input/touchscreen/Kconfig 
b/drivers/input/touchscreen/Kconfig
index 33c62e5..535b91a 100644
--- a/drivers/input/touchscreen/Kconfig
+++ b/drivers/input/touchscreen/Kconfig
@@ -96,8 +96,8 @@ config TOUCHSCREEN_AR1021_I2C
        tristate "Microchip AR1021 i2c touchscreen"
        depends on I2C && OF
        help
-         Say Y here if you have the Microchip AR1021 touchscreen controller
-         chip in your system.
+         Say Y here if you have the Microchip AR1020 or AR1021 touchscreen
+         controller chip in your system.
 
          If unsure, say N.
 
diff --git a/drivers/input/touchscreen/ar1021_i2c.c 
b/drivers/input/touchscreen/ar1021_i2c.c
index 2e7500e..03784d2 100644
--- a/drivers/input/touchscreen/ar1021_i2c.c
+++ b/drivers/input/touchscreen/ar1021_i2c.c
@@ -1,5 +1,5 @@
 /*
  * Microchip AR1021 driver for I2C
  *
  * Author: Christian Gmeiner <christian.gmei...@gmail.com>
  *
@@ -175,5 +175,5 @@ static struct i2c_driver ar1021_i2c_driver = {
 module_i2c_driver(ar1021_i2c_driver);
 
 MODULE_AUTHOR("Christian Gmeiner <christian.gmei...@gmail.com>");
-MODULE_DESCRIPTION("Microchip AR1021 I2C Driver");
+MODULE_DESCRIPTION("Microchip AR1020 and AR1021 I2C Driver");
 MODULE_LICENSE("GPL");
@@ -1,5 +1,5 @@
 /*
- * Microchip AR1021 driver for I2C
+ * Microchip AR1020 and AR1021 driver for I2C
  *
  * Author: Christian Gmeiner <christian.gmei...@gmail.com>
-- 
2.1.4

Reply via email to